{
  inputs = {
    nixpkgs.url = "github:nixos/nixpkgs";
    flake-utils.url = "github:numtide/flake-utils";
    nur = {
      url = "git+https://git.jojodev.com/jolheiser/nur";
      inputs.nixpkgs.follows = "nixpkgs";
    };
    tailwind-ctp = {
      url = "git+https://git.jojodev.com/jolheiser/tailwind-ctp";
      inputs.nixpkgs.follows = "nixpkgs";
    };
    tailwind-ctp-lsp = {
      url = "git+https://git.jojodev.com/jolheiser/tailwind-ctp-intellisense";
      inputs.nixpkgs.follows = "nixpkgs";
    };
  };

  outputs = {
    self,
    flake-utils,
    nixpkgs,
    nur,
    tailwind-ctp,
    tailwind-ctp-lsp,
  } @ inputs:
    flake-utils.lib.eachDefaultSystem (
      system: let
        pkgs = nixpkgs.legacyPackages.${system};
        nur = inputs.nur.packages.${system};
        tailwind-ctp = inputs.tailwind-ctp.packages.${system}.default;
        tailwind-ctp-lsp = inputs.tailwind-ctp-lsp.packages.${system}.default;
      in {
        packages.default = pkgs.buildGoModule {
          pname = "jolheiser.com";
          version = "site";
          src = ./.;
          vendorHash = "sha256-i/A6k0xaIPuWCfK6pm7TczkRaIWXzAjOGTXLIeDbxRw=";
          nativeBuildInputs = [nur.templ tailwind-ctp];
          excludedPackages = ".";
          postBuild = ''
            go generate
            mv dist $out
          '';
        };
        devShells.default = pkgs.mkShell {
          nativeBuildInputs = with pkgs; [
            go
            nur.templ
            tailwind-ctp
            tailwind-ctp-lsp
            vscode-langservers-extracted
          ];
        };
      }
    );
}
